// Search.cs
// Written by David J. Stein, Esq. See "License.html" for terms and conditions of use.
//
// This module contains the code for the search engine configuration window. It's just a list management
// module with some XML read/write stuff.

#region Using declarations

using System;
using System.IO;
using System.Collections;
using System.Text.RegularExpressions;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

#endregion

namespace SearchNS {

	public partial class ConfigureSearch : Form {

		#region Initialization code

		public ConfigureSearch() {
			InitializeComponent();
		}

		#endregion

		#region Button-click event handlers

		private void btnNew_Click(object sender, EventArgs e) {
			ListViewItem item = new ListViewItem(new string[] { "New Item", "http://" });
			lvSearchEngines.Items.Add(item);
			lvSearchEngines.SelectedItems.Clear();
			item.Selected = true;
			lvSearchEngines.TopItem = item;
		}

		private void btnSave_Click(object sender, EventArgs e) {
			if (lvSearchEngines.SelectedItems.Count == 1) {
				lvSearchEngines.SelectedItems[0].SubItems[0].Text = txtName.Text;
				lvSearchEngines.SelectedItems[0].SubItems[1].Text = txtURL.Text;
			} else {
				ListViewItem item = new ListViewItem(new string[] { "New Item", "http://" });
				lvSearchEngines.Items.Add(item);
				item.Selected = true;
				lvSearchEngines.TopItem = item;
			}
		}

		private void btnMoveUp_Click(object sender, EventArgs e) {
			if (lvSearchEngines.SelectedItems.Count == 1) {
				ListViewItem item = lvSearchEngines.SelectedItems[0];
				int iIndex = lvSearchEngines.Items.IndexOf(item);
				if (iIndex > 0) {
					lvSearchEngines.Items.Remove(item);
					lvSearchEngines.Items.Insert(iIndex - 1, item);
					item.Selected = true;
				}
			}
		}

		private void btnMoveDown_Click(object sender, EventArgs e) {
			if (lvSearchEngines.SelectedItems.Count == 1) {
				ListViewItem item = lvSearchEngines.SelectedItems[0];
				int iIndex = lvSearchEngines.Items.IndexOf(item);
				if (iIndex < lvSearchEngines.Items.Count - 1) {
					lvSearchEngines.Items.Remove(item);
					lvSearchEngines.Items.Insert(iIndex + 1, item);
					item.Selected = true;
				}
			}
		}

		private void btnDelete_Click(object sender, EventArgs e) {
			if (lvSearchEngines.SelectedItems.Count == 1)
				lvSearchEngines.Items.Remove(lvSearchEngines.SelectedItems[0]);
		}

		private void btnOK_Click(object sender, EventArgs e) {
			WriteSearchEnginesXML();
			Close();
		}

		#endregion

		#region Other vent handlers

		private void ConfigureSearch_Load(object sender, EventArgs e) {
			ReadSearchEnginesXML();
		}

		private void ConfigureSearch_Resize(object sender, EventArgs e) {
			columnURL.Width = Width - 205;
		}

		private void lvSearchEngines_SelectedIndexChanged(object sender, EventArgs e) {
			if (lvSearchEngines.SelectedItems.Count == 1) {
				txtName.Text = lvSearchEngines.SelectedItems[0].SubItems[0].Text;
				txtURL.Text = lvSearchEngines.SelectedItems[0].SubItems[1].Text;
				txtName.ReadOnly = txtURL.ReadOnly = false;
				btnSave.Enabled = btnDelete.Enabled = btnMoveUp.Enabled = btnMoveDown.Enabled = true;
			} else {
				txtName.Text = txtURL.Text = "";
				txtName.ReadOnly = txtURL.ReadOnly = true;
				btnSave.Enabled = btnDelete.Enabled = btnMoveUp.Enabled = btnMoveDown.Enabled = false;
			}
		}

		#endregion

		#region Helper functions

		private void ReadSearchEnginesXML() {
			ArrayList arraySearchEngines = Search.ReadSearchEnginesXML();
			lvSearchEngines.BeginUpdate();
			lvSearchEngines.Items.Clear();
			foreach (SearchEngine engine in arraySearchEngines)
				lvSearchEngines.Items.Add(new ListViewItem(new string[] { engine.strName, engine.strURL }));
			lvSearchEngines.EndUpdate();
			lvSearchEngines.Refresh();
		}

		private void WriteSearchEnginesXML() {
			try {
				StreamWriter stream = new StreamWriter(Application.StartupPath + "\\Search Engines.xml", false);
				stream.WriteLine("<?xml version='1.0' ?>");
				stream.WriteLine("<SearchEngines>");
				foreach (ListViewItem item in lvSearchEngines.Items) {
					stream.WriteLine(" <SearchEngine>");
					stream.WriteLine("  <Name>" + item.SubItems[0].Text + "</Name>");
					stream.WriteLine("  <URL>" + item.SubItems[1].Text + "</URL>");
					stream.WriteLine(" </SearchEngine>");
				}
				stream.WriteLine("</SearchEngines>");
				stream.Close();
			} catch (Exception ex) {
				MessageBox.Show("Error writing search engines file: " + ex.Message);
			}
		}

		#endregion

	}
}
